@@ -1,256 +1,144 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="da" sourcelanguage="en">
-<context>
-    <name>DataModel</name>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Error</source>
-        <translation>Fejl</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Session conflicts with other sessions.</source>
-        <translation>Sessionen er i konflikt med andre sessioner.</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="256"/>
-        <location filename="../src/data_model.cpp" line="470"/>
-        <source>Total</source>
-        <translation>Total</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="454"/>
-        <source>Date</source>
-        <translation>Dato</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="456"/>
-        <source>Start</source>
-        <translation>Start</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="458"/>
-        <source>Stop</source>
-        <translation>Slut</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="460"/>
-        <location filename="../src/window.cpp" line="138"/>
-        <source>Task</source>
-        <translation>Opgave</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="462"/>
-        <source>Hours</source>
-        <translation>Timer</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="464"/>
-        <source>Daily</source>
-        <translation>Daglig</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="466"/>
-        <source>Weekly</source>
-        <translation>Ugentlig</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="468"/>
-        <source>Monthly</source>
-        <translation>Månedlig</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="472"/>
-        <source>Report</source>
-        <translation>Rapportér</translation>
-    </message>
-</context>
+<TS version="2.1" language="da" sourcelanguage="en">
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="51"/>
         <source>Select application language:</source>
         <translation>Vælg sprog:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="54"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Systemsprog&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Note</source>
         <translation>Bemærk</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Programmet skal genstartes før ændringen træder i kraft.</translation>
     </message>
 </context>
-<context>
-    <name>Rates</name>
-    <message>
-        <location filename="../src/rates.cpp" line="36"/>
-        <source>$</source>
-        <translation>$</translation>
-    </message>
-</context>
 <context>
     <name>Report</name>
     <message>
-        <location filename="../src/report.cpp" line="361"/>
         <source>Time Sheet Report</source>
         <translation>Timeseddel</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="70"/>
         <source>Name:</source>
         <translation>Navn:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="71"/>
         <source>Company:</source>
         <translation>Firma:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="72"/>
         <source>Address:</source>
         <translation>Adresse:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="73"/>
         <source>Phone:</source>
         <translation>Telefon:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="74"/>
         <source>Fax:</source>
         <translation>Fax:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="75"/>
         <source>Email:</source>
         <translation>E-mail:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="76"/>
         <source>Website:</source>
         <translation>Hjemmeside:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="104"/>
-        <location filename="../src/report.cpp" line="109"/>
         <source>N/A</source>
         <translation>Ikke tilgængelig</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="113"/>
         <source>Prepend currency symbol</source>
         <translation>Tilføj valutasymbol i begyndelsen</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="120"/>
         <source>Hourly rate:</source>
         <translation>Timeløn:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="121"/>
         <source>Tax rate:</source>
         <translation>Skatteprocent:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="122"/>
         <source>Currency symbol:</source>
         <translation>Valutasymbol:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="137"/>
         <source>Contact Information</source>
         <translation>Kontaktinformation</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="138"/>
         <source>Data</source>
         <translation>Data</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="139"/>
         <source>Preview</source>
         <translation>Forhåndsvisning</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="145"/>
         <source>Export</source>
         <translation>Eksportér</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="146"/>
         <source>Print</source>
         <translation>Udskriv</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="269"/>
         <source>Web Page (*.html *.htm)</source>
         <translation>Hjemmeside (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="270"/>
         <source>iCalendar (*.ics)</source>
         <translation>iCalendar (*.ics)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="271"/>
         <source>Outlook CSV (*.csv)</source>
         <translation>Outlook CSV (*.csv)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="282"/>
         <source>Export Report</source>
         <translation>Eksporteret rapport</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="317"/>
         <source>View Reports</source>
         <translation>Vis rapporter</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="333"/>
         <source>Create Report</source>
         <translation>Opret rapport</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="388"/>
         <source>Phone: %1</source>
         <translation>Telefon: %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="392"/>
         <source>Fax: %1</source>
         <translation>Fax: %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="448"/>
         <source>Hours</source>
         <translation>Timer</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="455"/>
         <source>Subtotal</source>
         <translation>Subtotal</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="457"/>
         <source>Taxes</source>
         <translation>Skatter</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="460"/>
         <source>Total</source>
         <translation>Total</translation>
     </message>
@@ -258,7 +146,6 @@
 <context>
     <name>Session</name>
     <message numerus="yes">
-        <location filename="../src/session.cpp" line="50"/>
         <source>%n hour(s)</source>
         <translation>
             <numerusform>one: %n time</numerusform>
@@ -266,314 +153,302 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/session.cpp" line="52"/>
         <source>%L1 hours</source>
         <translation>%L1 timer</translation>
     </message>
 </context>
+<context>
+    <name>SessionDelegate</name>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Fejl</translation>
+    </message>
+    <message>
+        <source>Session conflicts with other sessions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SessionDialog</name>
     <message>
-        <location filename="../src/session_dialog.cpp" line="33"/>
         <source>Add Session</source>
         <translation>Tilføj session</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="54"/>
         <source>Date:</source>
         <translation>Dato:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="55"/>
         <source>Start:</source>
         <translation>Start:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="56"/>
         <source>Stop:</source>
         <translation>Slut:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="57"/>
         <source>Task:</source>
         <translation>Opgave:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="70"/>
         <source>Edit Session</source>
         <translation>Rediger session</translation>
     </message>
 </context>
+<context>
+    <name>SessionModel</name>
+    <message>
+        <source>Total</source>
+        <translation type="unfinished">Total</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation type="unfinished">Stop</translation>
+    </message>
+    <message>
+        <source>Task</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours</source>
+        <translation type="unfinished">Timer</translation>
+    </message>
+    <message>
+        <source>Daily</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Monthly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/window.cpp" line="120"/>
         <source>00:00:00</source>
         <translation>00:00:00</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="144"/>
         <source>Start</source>
         <translation>Start</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="149"/>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="155"/>
         <source>Cancel</source>
         <translation>Annuller</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="171"/>
+        <source>&amp;Minimize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>&amp;Project</source>
         <translation>&amp;Projekt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
-        <location filename="../src/window.cpp" line="184"/>
         <source>&amp;Add</source>
         <translation>&amp;Tilføj</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Shift+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
-        <location filename="../src/window.cpp" line="187"/>
         <source>&amp;Remove</source>
         <translation>&amp;Fjern</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
         <source>Ctrl+Shift+Delete</source>
         <translation>Ctrl+Shift+Delete</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>&amp;Quit</source>
         <translation>&amp;Afslut</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="183"/>
         <source>&amp;Session</source>
         <translation>&amp;Session</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="185"/>
         <source>&amp;Edit</source>
         <translation>&amp;Rediger</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="187"/>
         <source>Ctrl+Delete</source>
         <translation>Ctrl+Delete</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="190"/>
         <source>S&amp;ettings</source>
         <translation>I&amp;ndstillinger</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="191"/>
         <source>Columns</source>
         <translation>Kolonner</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="192"/>
         <source>&amp;Decimal Totals</source>
         <translation>&amp;Timer i decimaler</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="196"/>
         <source>&amp;Inline Editing</source>
         <translation>&amp;Direkte redigering</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="201"/>
         <source>Application &amp;Language...</source>
         <translation>&amp;Sprog...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="203"/>
         <source>&amp;Help</source>
         <translation>&amp;Hjælp</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="204"/>
         <source>&amp;About</source>
         <translation>&amp;Om</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="205"/>
         <source>About &amp;Qt</source>
         <translation>Om &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Project</source>
         <translation>Projekt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Timer</source>
         <translation>Timer</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="241"/>
         <source>Show all</source>
         <translation>Vis alt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="242"/>
         <source>Show only unbilled</source>
         <translation>Vis kun ubetalte</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="243"/>
         <source>Show only this year</source>
         <translation>Vis kun dette år</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="244"/>
         <source>Show only this month</source>
         <translation>Vis kun denne måned</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="245"/>
         <source>Show only this week</source>
         <translation>Vis kun denne uge</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="426"/>
         <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="427"/>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Frigivet under &lt;a href=%1&gt;GPL 3&lt;/a&gt;-licens</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
+        <source>Session conflicts with other sessions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Restore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Unable to read time data.</source>
         <translation>Kan ikke aflæse tidsdata.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="593"/>
-        <location filename="../src/window.cpp" line="829"/>
-        <location filename="../src/window.cpp" line="925"/>
         <source>Untitled</source>
         <translation>Unavngivet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
         <source>Unable to write time data.</source>
         <translation>Kan ikke opgøre tidsdata.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>There are timers running. Stop timers and quit?</source>
         <translation>Timere kører. Stop timere og afslut?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="423"/>
         <source>About</source>
         <translation>Om</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="425"/>
         <source>A program to help track spent time</source>
         <translation>Et program til at holde styr på tidsforbruget</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
-        <location filename="../src/window.cpp" line="487"/>
-        <location filename="../src/window.cpp" line="559"/>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Question</source>
         <translation>Spørgsmål</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="176"/>
         <source>&amp;Create Report...</source>
         <translation>&amp;Opret rapport...</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="178"/>
         <source>View R&amp;eports</source>
         <translation>Vis R&amp;apporter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>Cancel this session?</source>
         <translation>Annuller denne session?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Add Project</source>
         <translation>Tilføj projekt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Enter project name:</source>
         <translation>Angiv projektnavn:</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="124"/>
-        <location filename="../src/main.cpp" line="133"/>
-        <location filename="../src/window.cpp" line="542"/>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
         <source>Error</source>
         <translation>Fejl</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="133"/>
         <source>Unable to create time data location.</source>
         <translation>Kunne ikke oprette placering.</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="124"/>
         <source>Unable to move time data location.</source>
         <translation>Kunne ikke flytte placering.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="542"/>
         <source>A project with that name already exists.</source>
         <translation>Et projekt med dette navn eksisterer allerede.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="559"/>
         <source>Remove selected project?</source>
         <translation>Fjern valgte projekt?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Remove selected session?</source>
         <translation>Fjern valgte session?</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/window.cpp" line="1004"/>
         <source>%n timer(s) running</source>
         <translation>
             <numerusform>%n timer kører</numerusform>
@@ -581,11 +456,31 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="424"/>
-        <location filename="../src/window.cpp" line="1001"/>
-        <location filename="../src/window.cpp" line="1011"/>
         <source>Kapow Punch Clock</source>
         <translation>Kapow Punch Clock</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Punch clock program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Store settings as INI format in specified file.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not create automatic backups of time data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The time data file to use.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
