@@ -1,256 +1,144 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="es" sourcelanguage="en">
-<context>
-    <name>DataModel</name>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Error</source>
-        <translation>Error</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Session conflicts with other sessions.</source>
-        <translation>La sesión provoca conflictos con otras sesiones.</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="256"/>
-        <location filename="../src/data_model.cpp" line="470"/>
-        <source>Total</source>
-        <translation>Total</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="454"/>
-        <source>Date</source>
-        <translation>Fecha</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="456"/>
-        <source>Start</source>
-        <translation>Comenzar</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="458"/>
-        <source>Stop</source>
-        <translation>Detener</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="460"/>
-        <location filename="../src/window.cpp" line="138"/>
-        <source>Task</source>
-        <translation>Tarea</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="462"/>
-        <source>Hours</source>
-        <translation>Horas</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="464"/>
-        <source>Daily</source>
-        <translation>Diariamente</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="466"/>
-        <source>Weekly</source>
-        <translation>Semanalmente</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="468"/>
-        <source>Monthly</source>
-        <translation>Mensualmente</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="472"/>
-        <source>Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
+<TS version="2.1" language="es" sourcelanguage="en">
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="51"/>
         <source>Select application language:</source>
         <translation>Seleccione el idioma de la aplicación:</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="54"/>
         <source>&lt;System Language&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;Idioma del sistema&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Note</source>
         <translation>Nota</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Please restart this application for the change in language to take effect.</source>
-        <translation>Por favor, reinicie la aplicación para el cambio de idioma tenga efecto.</translation>
-    </message>
-</context>
-<context>
-    <name>Rates</name>
-    <message>
-        <location filename="../src/rates.cpp" line="36"/>
-        <source>$</source>
-        <translation type="unfinished"></translation>
+        <translation>Reinicie la aplicación para el cambio de idioma surta efecto.</translation>
     </message>
 </context>
 <context>
     <name>Report</name>
     <message>
-        <location filename="../src/report.cpp" line="361"/>
         <source>Time Sheet Report</source>
         <translation>Informe de horas trabajadas</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="70"/>
         <source>Name:</source>
         <translation>Nombre:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="71"/>
         <source>Company:</source>
-        <translation>Compañía:</translation>
+        <translation>Empresa:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="72"/>
         <source>Address:</source>
         <translation>Dirección:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="73"/>
         <source>Phone:</source>
         <translation>Teléfono:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="74"/>
         <source>Fax:</source>
         <translation>Fax:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="75"/>
         <source>Email:</source>
         <translation>Correo electrónico:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="76"/>
         <source>Website:</source>
         <translation>Página web:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="104"/>
-        <location filename="../src/report.cpp" line="109"/>
         <source>N/A</source>
-        <translation>N/A</translation>
+        <translation>N/D</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="113"/>
         <source>Prepend currency symbol</source>
         <translation>Anteponer símbolo de moneda</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="120"/>
         <source>Hourly rate:</source>
         <translation>Tarifa por hora:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="121"/>
         <source>Tax rate:</source>
         <translation>Tasa de impuesto:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="122"/>
         <source>Currency symbol:</source>
         <translation>Símbolo de moneda:</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="137"/>
         <source>Contact Information</source>
-        <translation>Información de Contacto</translation>
+        <translation>Información de contacto</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="138"/>
         <source>Data</source>
         <translation>Datos</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="139"/>
         <source>Preview</source>
-        <translation>Vista previa</translation>
+        <translation>Previsualización</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="145"/>
         <source>Export</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportar</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="146"/>
         <source>Print</source>
         <translation>Imprimir</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="269"/>
         <source>Web Page (*.html *.htm)</source>
-        <translation type="unfinished"></translation>
+        <translation>Página web (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="270"/>
         <source>iCalendar (*.ics)</source>
-        <translation type="unfinished"></translation>
+        <translation>iCalendar (*.ics)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="271"/>
         <source>Outlook CSV (*.csv)</source>
-        <translation type="unfinished"></translation>
+        <translation>CSV de Outlook (*.csv)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="282"/>
         <source>Export Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportar el informe</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="317"/>
         <source>View Reports</source>
-        <translation type="unfinished"></translation>
+        <translation>Ver los informes</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="333"/>
         <source>Create Report</source>
-        <translation type="unfinished"></translation>
+        <translation>Crear informe</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="388"/>
         <source>Phone: %1</source>
         <translation>Teléfono: %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="392"/>
         <source>Fax: %1</source>
         <translation>Fax: %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="448"/>
         <source>Hours</source>
         <translation>Horas</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="455"/>
         <source>Subtotal</source>
         <translation>Subtotal</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="457"/>
         <source>Taxes</source>
         <translation>Impuestos</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="460"/>
         <source>Total</source>
         <translation>Total</translation>
     </message>
@@ -258,7 +146,6 @@
 <context>
     <name>Session</name>
     <message numerus="yes">
-        <location filename="../src/session.cpp" line="50"/>
         <source>%n hour(s)</source>
         <translation>
             <numerusform>%n hora</numerusform>
@@ -266,314 +153,302 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/session.cpp" line="52"/>
         <source>%L1 hours</source>
         <translation>%L1 horas</translation>
     </message>
 </context>
+<context>
+    <name>SessionDelegate</name>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Error</translation>
+    </message>
+    <message>
+        <source>Session conflicts with other sessions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SessionDialog</name>
     <message>
-        <location filename="../src/session_dialog.cpp" line="33"/>
         <source>Add Session</source>
         <translation>Añadir sesión</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="54"/>
         <source>Date:</source>
         <translation>Fecha:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="55"/>
         <source>Start:</source>
         <translation>Inicio:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="56"/>
         <source>Stop:</source>
         <translation>Fin:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="57"/>
         <source>Task:</source>
         <translation>Tarea:</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="70"/>
         <source>Edit Session</source>
-        <translation>Editar Sesión</translation>
+        <translation>Editar sesión</translation>
+    </message>
+</context>
+<context>
+    <name>SessionModel</name>
+    <message>
+        <source>Total</source>
+        <translation type="unfinished">Total</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Iniciar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation type="unfinished">Detener</translation>
+    </message>
+    <message>
+        <source>Task</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours</source>
+        <translation type="unfinished">Horas</translation>
+    </message>
+    <message>
+        <source>Daily</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Monthly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/window.cpp" line="120"/>
         <source>00:00:00</source>
         <translation>00:00:00</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="144"/>
         <source>Start</source>
         <translation>Iniciar</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="149"/>
         <source>Stop</source>
         <translation>Detener</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="155"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="171"/>
+        <source>&amp;Minimize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>&amp;Project</source>
         <translation>&amp;Proyecto</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
-        <location filename="../src/window.cpp" line="184"/>
         <source>&amp;Add</source>
         <translation>&amp;Añadir</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
         <source>Ctrl+Shift+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Mayús+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
-        <location filename="../src/window.cpp" line="187"/>
         <source>&amp;Remove</source>
         <translation>&amp;Remover</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
         <source>Ctrl+Shift+Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Mayús+Supr</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>&amp;Quit</source>
         <translation>&amp;Salir</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="183"/>
         <source>&amp;Session</source>
         <translation>&amp;Sesión</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="185"/>
         <source>&amp;Edit</source>
         <translation>&amp;Editar</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="187"/>
         <source>Ctrl+Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Supr</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="190"/>
         <source>S&amp;ettings</source>
-        <translation>&amp;Configuraciones</translation>
+        <translation>&amp;Configuración</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="191"/>
         <source>Columns</source>
         <translation>Columnas</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="192"/>
         <source>&amp;Decimal Totals</source>
         <translation>&amp;Totales decimales</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="196"/>
         <source>&amp;Inline Editing</source>
-        <translation>&amp;Edición en Línea</translation>
+        <translation>&amp;Edición en la misma línea</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="201"/>
         <source>Application &amp;Language...</source>
-        <translation>Idioma de la &amp;Aplicación...</translation>
+        <translation>&amp;Idioma de la aplicación…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="203"/>
         <source>&amp;Help</source>
-        <translation>&amp;Ayuda</translation>
+        <translation>Ay&amp;uda</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="204"/>
         <source>&amp;About</source>
         <translation>&amp;Acerca de</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="205"/>
         <source>About &amp;Qt</source>
         <translation>Acerca de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Project</source>
         <translation>Proyecto</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Timer</source>
         <translation>Temporizador</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="241"/>
         <source>Show all</source>
         <translation>Mostrar todo</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="242"/>
         <source>Show only unbilled</source>
-        <translation>Mostrar sólo no facturados</translation>
+        <translation>Mostrar solo no facturados</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="243"/>
         <source>Show only this year</source>
-        <translation>Mostrar sólo este año</translation>
+        <translation>Mostrar solo este año</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="244"/>
         <source>Show only this month</source>
-        <translation>Mostrar sólo este mes</translation>
+        <translation>Mostrar solo este mes</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="245"/>
         <source>Show only this week</source>
-        <translation>Mostrar sólo esta semana</translation>
+        <translation>Mostrar solo esta semana</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="426"/>
         <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="427"/>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
+        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
+    </message>
+    <message>
+        <source>Session conflicts with other sessions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Restore</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
         <source>Unable to read time data.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se pudieron leer los datos del tiempo.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="593"/>
-        <location filename="../src/window.cpp" line="829"/>
-        <location filename="../src/window.cpp" line="925"/>
         <source>Untitled</source>
         <translation>Sin título</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
         <source>Unable to write time data.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se pudieron escribir los datos del tiempo.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>There are timers running. Stop timers and quit?</source>
-        <translation type="unfinished"></translation>
+        <translation>Hay temporizadores en ejecución. ¿Quiere detenerlos y salir?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="423"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="425"/>
         <source>A program to help track spent time</source>
         <translation>Un programa para ayudar a rastrear tiempo consumido</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
-        <location filename="../src/window.cpp" line="487"/>
-        <location filename="../src/window.cpp" line="559"/>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Question</source>
         <translation>Pregunta</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="176"/>
         <source>&amp;Create Report...</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Crear el informe…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="178"/>
         <source>View R&amp;eports</source>
-        <translation type="unfinished"></translation>
+        <translation>Ver los in&amp;formes</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>Cancel this session?</source>
-        <translation>¿Cancelar esta sesión?</translation>
+        <translation>¿Quiere cancelar esta sesión?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Add Project</source>
-        <translation>Agregar proyecto</translation>
+        <translation>Añadir un proyecto</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Enter project name:</source>
         <translation>Escriba el nombre del proyecto:</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="124"/>
-        <location filename="../src/main.cpp" line="133"/>
-        <location filename="../src/window.cpp" line="542"/>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="133"/>
         <source>Unable to create time data location.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se pudo crear la ubicación de datos del tiempo.</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="124"/>
         <source>Unable to move time data location.</source>
-        <translation type="unfinished"></translation>
+        <translation>No se pudo mover la ubicación de datos del tiempo.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="542"/>
         <source>A project with that name already exists.</source>
-        <translation>Un proyecto con ese nombre ya existe.</translation>
+        <translation>Ya existe un proyecto con ese nombre.</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="559"/>
         <source>Remove selected project?</source>
-        <translation>¿Remover proyecto seleccionado?</translation>
+        <translation>¿Quiere eliminar el proyecto seleccionado?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Remove selected session?</source>
-        <translation>¿Remover sesión seleccionada?</translation>
+        <translation>¿Quiere eliminar la sesión seleccionada?</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/window.cpp" line="1004"/>
         <source>%n timer(s) running</source>
         <translation>
             <numerusform>%n temporizador ejecutándose</numerusform>
@@ -581,11 +456,31 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="424"/>
-        <location filename="../src/window.cpp" line="1001"/>
-        <location filename="../src/window.cpp" line="1011"/>
         <source>Kapow Punch Clock</source>
-        <translation>Kapow Punch Clock</translation>
+        <translation>Reloj de control Kapow</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Punch clock program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Store settings as INI format in specified file.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not create automatic backups of time data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The time data file to use.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
