@@ -1,256 +1,144 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="fr" sourcelanguage="en">
-<context>
-    <name>DataModel</name>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Error</source>
-        <translation>Erreur</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="92"/>
-        <location filename="../src/data_model.cpp" line="99"/>
-        <location filename="../src/data_model.cpp" line="541"/>
-        <source>Session conflicts with other sessions.</source>
-        <translation>Conflit (horaire) avec au moins une autre session.</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="256"/>
-        <location filename="../src/data_model.cpp" line="470"/>
-        <source>Total</source>
-        <translation>Total</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="454"/>
-        <source>Date</source>
-        <translation>Date</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="456"/>
-        <source>Start</source>
-        <translation>Début</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="458"/>
-        <source>Stop</source>
-        <translation>Fin</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="460"/>
-        <location filename="../src/window.cpp" line="138"/>
-        <source>Task</source>
-        <translation>Tâche</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="462"/>
-        <source>Hours</source>
-        <translation>Heures</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="464"/>
-        <source>Daily</source>
-        <translation>Journalier</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="466"/>
-        <source>Weekly</source>
-        <translation>Hebdomadaire</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="468"/>
-        <source>Monthly</source>
-        <translation>Mensuel</translation>
-    </message>
-    <message>
-        <location filename="../src/data_model.cpp" line="472"/>
-        <source>Report</source>
-        <translation>Rapport</translation>
-    </message>
-</context>
+<TS version="2.1" language="fr" sourcelanguage="en">
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="51"/>
         <source>Select application language:</source>
         <translation>Sélectionner la langue pour l&apos;application :</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="54"/>
         <source>&lt;System Language&gt;</source>
         <translation>&lt;Langue du système&gt;</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Note</source>
         <translation>Remarque</translation>
     </message>
     <message>
-        <location filename="../src/locale_dialog.cpp" line="182"/>
         <source>Please restart this application for the change in language to take effect.</source>
         <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
     </message>
 </context>
-<context>
-    <name>Rates</name>
-    <message>
-        <location filename="../src/rates.cpp" line="36"/>
-        <source>$</source>
-        <translation>$</translation>
-    </message>
-</context>
 <context>
     <name>Report</name>
     <message>
-        <location filename="../src/report.cpp" line="361"/>
         <source>Time Sheet Report</source>
         <translation>Fiche horaire</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="70"/>
         <source>Name:</source>
         <translation>Nom : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="71"/>
         <source>Company:</source>
         <translation>Société : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="72"/>
         <source>Address:</source>
         <translation>Adresse : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="73"/>
         <source>Phone:</source>
         <translation>Téléphone : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="74"/>
         <source>Fax:</source>
         <translation>Télécopie : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="75"/>
         <source>Email:</source>
         <translation>Courriel : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="76"/>
         <source>Website:</source>
         <translation>Site WWW : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="104"/>
-        <location filename="../src/report.cpp" line="109"/>
         <source>N/A</source>
         <translation>N/A</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="113"/>
         <source>Prepend currency symbol</source>
         <translation>Faire précéder le symbole monétaire</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="120"/>
         <source>Hourly rate:</source>
         <translation>Taux horaire : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="121"/>
         <source>Tax rate:</source>
         <translation>TVA : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="122"/>
         <source>Currency symbol:</source>
         <translation>Symbole monétaire : </translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="137"/>
         <source>Contact Information</source>
         <translation>Informations sur le contact</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="138"/>
         <source>Data</source>
         <translation>Données</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="139"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="145"/>
         <source>Export</source>
         <translation>Exportation</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="146"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="269"/>
         <source>Web Page (*.html *.htm)</source>
         <translation>Page Web (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="270"/>
         <source>iCalendar (*.ics)</source>
         <translation>iCalendar (*.ics)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="271"/>
         <source>Outlook CSV (*.csv)</source>
         <translation>CSV Outlook (*.csv)</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="282"/>
         <source>Export Report</source>
         <translation>Exportation du rapport</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="317"/>
         <source>View Reports</source>
         <translation>Affichage des rapports</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="333"/>
         <source>Create Report</source>
         <translation>Création de rapport</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="388"/>
         <source>Phone: %1</source>
         <translation>Téléphone : %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="392"/>
         <source>Fax: %1</source>
         <translation>Télécopie : %1</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="448"/>
         <source>Hours</source>
         <translation>Heures</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="455"/>
         <source>Subtotal</source>
         <translation>Sous-total</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="457"/>
         <source>Taxes</source>
         <translation>TVA</translation>
     </message>
     <message>
-        <location filename="../src/report.cpp" line="460"/>
         <source>Total</source>
         <translation>Total</translation>
     </message>
@@ -258,7 +146,6 @@
 <context>
     <name>Session</name>
     <message numerus="yes">
-        <location filename="../src/session.cpp" line="50"/>
         <source>%n hour(s)</source>
         <translation>
             <numerusform>%n heure</numerusform>
@@ -266,314 +153,302 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/session.cpp" line="52"/>
         <source>%L1 hours</source>
         <translation>%L1 heures</translation>
     </message>
 </context>
+<context>
+    <name>SessionDelegate</name>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished">Erreur</translation>
+    </message>
+    <message>
+        <source>Session conflicts with other sessions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SessionDialog</name>
     <message>
-        <location filename="../src/session_dialog.cpp" line="33"/>
         <source>Add Session</source>
         <translation>Ajouter une session</translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="54"/>
         <source>Date:</source>
         <translation>Date : </translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="55"/>
         <source>Start:</source>
         <translation>Début : </translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="56"/>
         <source>Stop:</source>
         <translation>Fin : </translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="57"/>
         <source>Task:</source>
         <translation>Tâche : </translation>
     </message>
     <message>
-        <location filename="../src/session_dialog.cpp" line="70"/>
         <source>Edit Session</source>
         <translation>Modifier la session</translation>
     </message>
 </context>
+<context>
+    <name>SessionModel</name>
+    <message>
+        <source>Total</source>
+        <translation type="unfinished">Total</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished">Démarrer</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation type="unfinished">Arrêter</translation>
+    </message>
+    <message>
+        <source>Task</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hours</source>
+        <translation type="unfinished">Heures</translation>
+    </message>
+    <message>
+        <source>Daily</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Monthly</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Window</name>
     <message>
-        <location filename="../src/window.cpp" line="120"/>
         <source>00:00:00</source>
         <translation>00:00:00</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="144"/>
         <source>Start</source>
         <translation>Démarrer</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="149"/>
         <source>Stop</source>
         <translation>Arrêter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="155"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="171"/>
+        <source>&amp;Minimize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>&amp;Project</source>
         <translation>&amp;Projet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
-        <location filename="../src/window.cpp" line="184"/>
         <source>&amp;Add</source>
         <translation>&amp;Ajouter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="172"/>
         <source>Ctrl+Shift+N</source>
         <translation>Ctrl+Maj+N</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
-        <location filename="../src/window.cpp" line="187"/>
         <source>&amp;Remove</source>
         <translation>&amp;Supprimer</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="173"/>
         <source>Ctrl+Shift+Delete</source>
         <translation>Ctrl+Maj+Suppr</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="181"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="183"/>
         <source>&amp;Session</source>
         <translation>&amp;Session</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="185"/>
         <source>&amp;Edit</source>
         <translation>&amp;Modifier</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="187"/>
         <source>Ctrl+Delete</source>
         <translation>Ctrl+Suppr</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="190"/>
         <source>S&amp;ettings</source>
         <translation>&amp;Paramètres</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="191"/>
         <source>Columns</source>
         <translation>Colonnes</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="192"/>
         <source>&amp;Decimal Totals</source>
         <translation>Totaux &amp;décimaux</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="196"/>
         <source>&amp;Inline Editing</source>
         <translation>Mod&amp;ifiation en ligne</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="201"/>
         <source>Application &amp;Language...</source>
         <translation>&amp;Langue de l&apos;application…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="203"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="204"/>
         <source>&amp;About</source>
         <translation>À &amp;propos de…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="205"/>
         <source>About &amp;Qt</source>
         <translation>À propos de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Project</source>
         <translation>Projet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="212"/>
         <source>Timer</source>
         <translation>Minuteur</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="241"/>
         <source>Show all</source>
         <translation>Afficher tout</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="242"/>
         <source>Show only unbilled</source>
         <translation>Heures non-facturées uniquement</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="243"/>
         <source>Show only this year</source>
         <translation>Cette année uniquement</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="244"/>
         <source>Show only this month</source>
         <translation>Ce mois uniquement</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="245"/>
         <source>Show only this week</source>
         <translation>Cette semaine uniquement</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="426"/>
         <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="427"/>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
+        <source>Session conflicts with other sessions.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Restore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>Unable to read time data.</source>
         <translation>Lecture impossible des données d&apos;heure. </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="593"/>
-        <location filename="../src/window.cpp" line="829"/>
-        <location filename="../src/window.cpp" line="925"/>
         <source>Untitled</source>
         <translation>Sans titre</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
         <source>Unable to write time data.</source>
         <translation>Écriture impossible des données d&apos;heure. </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
         <source>There are timers running. Stop timers and quit?</source>
         <translation>Des minuteurs sont toujours en cours d&apos;exécution. Voulez-vous les arrêter et quitter ?</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="423"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="425"/>
         <source>A program to help track spent time</source>
         <translation>Programme d&apos;aide au suivi du temps passé</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="388"/>
-        <location filename="../src/window.cpp" line="487"/>
-        <location filename="../src/window.cpp" line="559"/>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Question</source>
         <translation>Question</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="176"/>
         <source>&amp;Create Report...</source>
         <translation>&amp;Créer un rapport…</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="178"/>
         <source>View R&amp;eports</source>
         <translation>&amp;Afficher les rapports</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="487"/>
         <source>Cancel this session?</source>
         <translation>Annuler cette session ? </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Add Project</source>
         <translation>Ajouter un projet</translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="536"/>
         <source>Enter project name:</source>
         <translation>Nom du projet : </translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="124"/>
-        <location filename="../src/main.cpp" line="133"/>
-        <location filename="../src/window.cpp" line="542"/>
-        <location filename="../src/window.cpp" line="756"/>
-        <location filename="../src/window.cpp" line="794"/>
-        <location filename="../src/window.cpp" line="837"/>
-        <location filename="../src/window.cpp" line="844"/>
-        <location filename="../src/window.cpp" line="911"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="113"/>
-        <location filename="../src/main.cpp" line="120"/>
-        <location filename="../src/main.cpp" line="133"/>
         <source>Unable to create time data location.</source>
         <translation>Création de l&apos;emplacement de données de date impossible. </translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="124"/>
         <source>Unable to move time data location.</source>
         <translation>Déplacement de l&apos;emplacement de données de date impossible. </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="542"/>
         <source>A project with that name already exists.</source>
         <translation>Un projet portant le même nom existe déjà. </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="559"/>
         <source>Remove selected project?</source>
         <translation>Supprimer le projet sélectionné ? </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="726"/>
         <source>Remove selected session?</source>
         <translation>Supprimer la session sélectionnée ? </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/window.cpp" line="1004"/>
         <source>%n timer(s) running</source>
         <translation>
             <numerusform>%n minuteur en cours</numerusform>
@@ -581,11 +456,31 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/window.cpp" line="424"/>
-        <location filename="../src/window.cpp" line="1001"/>
-        <location filename="../src/window.cpp" line="1011"/>
         <source>Kapow Punch Clock</source>
         <translation>Pointeuse Kapow</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Punch clock program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Store settings as INI format in specified file.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do not create automatic backups of time data.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The time data file to use.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
